package com.userauth.restuserauth.security;

import java.util.Date;
import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.springframework.stereotype.Service;

@Service
public class JwtBlacklistService {

    // 使用 ConcurrentHashMap 作为内存中的黑名单存储。
    // 在生产环境中，建议使用 Redis 等分布式缓存来支持多实例部署。
    private final Map<String, Date> blacklist = new ConcurrentHashMap<>();

    /**
     * 将令牌加入黑名单。
     * @param token 要加入黑名单的 JWT。
     */
    public void blacklistToken(String token) {
        // 为了简化，我们暂时不处理过期清理，直接加入。
        // 在实际应用中，可以存储令牌的过期时间，并定期清理已过期的令牌以防止内存泄漏。
        blacklist.put(token, new Date());
    }

    /**
     * 检查令牌是否存在于黑名单中。
     * @param token 要检查的 JWT。
     * @return 如果令牌在黑名单中，则返回 true，否则返回 false。
     */
    public boolean isBlacklisted(String token) {
        return blacklist.containsKey(token);
    }
}
